@@ -35,10 +35,7 @@ private Q_SLOTS:
     void testDateList();
     void testOptions();
     void testDisplayFormat();
-
-private:
-
-    KDateComboBox *m_combo;
+    void testSignals();
 };
 
 #endif // KDATECOMBOBOXTEST_H
